==> registry-service-5.0.3-20231218.181250-3-sources.jar: de/uniba/minf/registry/view/controller/UserController.java <==
package de.uniba.minf.registry.view.controller;

import java.io.IOException;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import de.uniba.minf.core.rest.exception.ApiItemNotFoundException;
import de.uniba.minf.core.rest.exception.ApiUnauthorizedException;
import de.uniba.minf.registry.model.PersistedUser;
import de.uniba.minf.registry.repository.UserGroupRepository;
import de.uniba.minf.registry.repository.UserRepository;
import eu.dariah.de.dariahsp.spring.mvc.model.AuthPojo;
import jakarta.servlet.http.HttpServletResponse;

@Controller
@RequestMapping("/user")
public class UserController extends BaseViewController {
	
	@Autowired private UserRepository userRepo;
	
	public UserController() {
		super("user");
	}
	
	@GetMapping
	public String redirectHome(HttpServletResponse response) throws IOException  {
		response.sendRedirect("profile");
		return null;
	}
	
    @GetMapping("/profile")
    public String showProfile(Model model, HttpServletResponse response) throws ApiUnauthorizedException, ApiItemNotFoundException, IOException {
    	AuthPojo authPojo = authInfoHelper.getAuth();
		if (authPojo.getUserId()==null) {
			response.sendRedirect("/startLogin");
			return null;
		}
		Optional<PersistedUser> user = userRepo.findById(authPojo.getUserId());
		if (!user.isPresent()) {
			throw new ApiItemNotFoundException(authPojo.getUserId(), "user");
		}
		model.addAttribute("user", user.get());
        return "user/profile";
    }
    
    @GetMapping("/groups")
    public String showUserGroups(Model model, HttpServletResponse response) throws ApiUnauthorizedException, ApiItemNotFoundException, IOException {
    	AuthPojo authPojo = authInfoHelper.getAuth();
		if (authPojo.getUserId()==null) {
			response.sendRedirect("/startLogin");
			return null;
		}
		Optional<PersistedUser> user = userRepo.findById(authPojo.getUserId());
		if (!user.isPresent()) {
			throw new ApiItemNotFoundException(authPojo.getUserId(), "user");
		}
		
        return "user/groups";
    }
}

==> registry-service-5.2-20240410.064200-1-sources.jar: de/uniba/minf/registry/view/controller/UserController.java <==
package de.uniba.minf.registry.view.controller;

import java.io.IOException;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import de.uniba.minf.auth.spring.mvc.model.AuthPojo;
import de.uniba.minf.core.rest.exception.ApiItemNotFoundException;
import de.uniba.minf.core.rest.exception.ApiUnauthorizedException;
import de.uniba.minf.registry.model.PersistedUser;
import de.uniba.minf.registry.repository.UserGroupRepository;
import de.uniba.minf.registry.repository.UserRepository;
import jakarta.servlet.http.HttpServletResponse;

@Controller
@RequestMapping("/user")
public class UserController extends BaseViewController {
	
	@Autowired private UserRepository userRepo;
	
	public UserController() {
		super("user");
	}
	
	@GetMapping
	public String redirectHome(HttpServletResponse response) throws IOException  {
		response.sendRedirect("profile");
		return null;
	}
	
	@GetMapping("/profile")
    public String showProfile(Model model, HttpServletResponse response) throws ApiUnauthorizedException, ApiItemNotFoundException, IOException {
    	AuthPojo authPojo = authInfoHelper.getAuth();
		if (authPojo.getUserId()==null) {
			response.sendRedirect("/startLogin");
			return null;
		}
		Optional<PersistedUser> user = userRepo.findById(authPojo.getUserId());
		if (!user.isPresent()) {
			throw new ApiItemNotFoundException(authPojo.getUserId(), "user");
		}
		model.addAttribute("user", user.get());
        return "user/profile";
    }
	
    @GetMapping("/tokens")
    public String showTokens(Model model, HttpServletResponse response) throws ApiUnauthorizedException, ApiItemNotFoundException, IOException {
    	AuthPojo authPojo = authInfoHelper.getAuth();
		if (authPojo.getUserId()==null) {
			response.sendRedirect("/startLogin");
			return null;
		}
		Optional<PersistedUser> user = userRepo.findById(authPojo.getUserId());
		if (!user.isPresent()) {
			throw new ApiItemNotFoundException(authPojo.getUserId(), "user");
		}
		model.addAttribute("user", user.get());
        return "user/tokens";
    }
    
    @GetMapping("/groups")
    public String showUserGroups(Model model, HttpServletResponse response) throws ApiUnauthorizedException, ApiItemNotFoundException, IOException {
    	AuthPojo authPojo = authInfoHelper.getAuth();
		if (authPojo.getUserId()==null) {
			response.sendRedirect("/startLogin");
			return null;
		}
		Optional<PersistedUser> user = userRepo.findById(authPojo.getUserId());
		if (!user.isPresent()) {
			throw new ApiItemNotFoundException(authPojo.getUserId(), "user");
		}
		
        return "user/groups";
    }
}
